OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Non é posíbel escribir no directorio «config»!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Isto normalmente pódese solucionar dándolle ao servidor web acceso de escritura ao directorio de configuración.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Mais, se prefire manter o ficheiro config.php como de só lectura, estabeleza a opción «config_is_read_only» como verdadeira nel.",
    "See %s" : "Vexa %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "A aplicación %1$s non está presente ou ten unha versión non compatíbel con este servidor. Comprobe o directorio de aplicacións.",
    "Sample configuration detected" : "Detectouse a configuración de exemplo",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detectouse que foi copiada a configuración de exemplo. Isto pode rachar a súa instalación e non é compatíbel. Lea a documentación antes de facer cambios en config.php",
    "The page could not be found on the server." : "Non foi posíbel atopar a páxina no servidor.",
    "%s email verification" : "Verificación do correo-e %s",
    "Email verification" : "Verificación do correo-e",
    "Click the following button to confirm your email." : "Prema no seguinte botón para confirmar o seu correo-e.",
    "Click the following link to confirm your email." : "Prema na seguinte ligazón para confirmar o seu correo-e.",
    "Confirm your email" : "Confirmar o seu correo-e",
    "Other activities" : "Outras actividades",
    "%1$s and %2$s" : "%1$s e %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
    "Education bundle" : "Paquete de educación",
    "Enterprise bundle" : "Paquete empresarial",
    "Groupware bundle" : "Paquete de software colaborativo",
    "Hub bundle" : "Paquete de concentradores",
    "Public sector bundle" : "Paquete do sector público",
    "Social sharing bundle" : "Paquete para compartir en redes sociais",
    "PHP %s or higher is required." : "Precísase de PHP %s ou superior.",
    "PHP with a version lower than %s is required." : "Precísase de PHP cunha versión inferior a %s.",
    "%sbit or higher PHP required." : "Precísase de PHP para %s bits ou superior.",
    "The following architectures are supported: %s" : "Admítense as seguintes arquitecturas: %s",
    "The following databases are supported: %s" : "Admítense as seguintes bases de datos: %s",
    "The command line tool %s could not be found" : "Non foi posíbel atopar a ferramenta de liña de ordes %s",
    "The library %s is not available." : "Non está dispoñíbel a biblioteca %s.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Precísase da biblioteca %1$s cunha versión superior a %2$s - dispoñíbel a versión %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Precísase da biblioteca %1$s cunha versión inferior a %2$s - dispoñíbel a versión %3$s.",
    "The following platforms are supported: %s" : "Admítense as seguintes plataformas: %s",
    "Server version %s or higher is required." : "Precísase da versión %s ou superior do servidor.",
    "Server version %s or lower is required." : "Precísase da versión %s ou inferior do servidor.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "A conta que accede debe ser de administración, de subadministración ou ter dereitos especiais para acceder a este axuste",
    "Your current IP address doesn't allow you to perform admin actions" : "O seu enderezo IP actual non lle permite realizar accións de administración",
    "Logged in account must be an admin or sub admin" : "A conta que accede debe ser de administración ou de subadministración",
    "Logged in account must be an admin" : "A conta que accede debe ser de administración",
    "Wiping of device %s has started" : "Iniciouse a limpeza do dispositivo %s",
    "Wiping of device »%s« has started" : "Iniciouse a limpeza do dispositivo «%s»",
    "»%s« started remote wipe" : "«%s» iniciou a limpeza remota",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "O dispositivo ou aplicación «%s» iniciou o proceso remoto de limpeza. Recibirá outro correo  cando remate o proceso",
    "Wiping of device %s has finished" : "Rematou a limpeza do dispositivo %s",
    "Wiping of device »%s« has finished" : "Rematou a limpeza do dispositivo «%s»",
    "»%s« finished remote wipe" : "«%s» rematou a limpeza remota",
    "Device or application »%s« has finished the remote wipe process." : "O dispositivo ou aplicación «%s» rematou o proceso remoto de limpeza.",
    "Remote wipe started" : "Iniciouse a limpeza remota",
    "A remote wipe was started on device %s" : "Iniciouse unha limpeza remota no dispositivo %s",
    "Remote wipe finished" : "Rematou a limpeza remota",
    "The remote wipe on %s has finished" : "A limpeza remota en %s rematou",
    "Authentication" : "Autenticación",
    "Unknown filetype" : "Tipo de ficheiro descoñecido",
    "Invalid image" : "Imaxe incorrecta",
    "Avatar image is not square" : "A imaxe do avatar non é cadrada",
    "Files" : "Ficheiros",
    "View profile" : "Ver o perfil",
    "same time" : "ao mesmo tempo",
    "_%nh_::_%nh_" : ["%nh","%nh"],
    "_%nm_::_%nm_" : ["%nm","%nm"],
    "%s ahead" : "%s antes",
    "%s behind" : "%s após",
    "Local time: %s" : "Hora local: %s",
    "today" : "hoxe",
    "tomorrow" : "mañá",
    "yesterday" : "onte",
    "_in %n day_::_in %n days_" : ["en %n día","en %n días"],
    "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n días"],
    "next month" : "o vindeiro mes",
    "last month" : "o mes pasado",
    "_in %n month_::_in %n months_" : ["en %n mes","en %n meses"],
    "_%n month ago_::_%n months ago_" : ["Hai %n mes","Hai %n meses"],
    "next year" : "o vindeiro ano",
    "last year" : "o ano pasado",
    "_in %n year_::_in %n years_" : ["en %n ano","en %n anos"],
    "_%n year ago_::_%n years ago_" : ["Hai %n ano","Hai %n anos"],
    "_in %n hour_::_in %n hours_" : ["en %n hora","en %n horas"],
    "_%n hour ago_::_%n hours ago_" : ["Hai %n hora","Hai %n horas"],
    "_in %n minute_::_in %n minutes_" : ["en %n minuto","en %n minutos"],
    "_%n minute ago_::_%n minutes ago_" : ["Hai %n minuto","Hai %n minutos"],
    "in a few seconds" : "en poucos segundos",
    "seconds ago" : "segundos atrás",
    "Empty file" : "Ficheiro baleiro",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Non existe o módulo co ID: %s. Actíveo nos axustes das aplicacións ou contacte coa administración desta instancia.",
    "No file conversion providers available" : "Non hai ningún provedor de conversión de ficheiros dispoñíbel",
    "File is too large to convert" : "O ficheiro é demasiado grande para convertelo",
    "Destination does not match conversion extension" : "O destino non coincide coa extensión de conversión",
    "Could not convert file" : "Non foi posíbel converter o ficheiro",
    "Destination does not exist" : "Non existe ese destino",
    "Destination is not creatable" : "Non é posíbel crear o destino",
    "Dot files are not allowed" : "Non se admiten os ficheiros con punto",
    "%1$s (renamed)" : "%1$s (renomeado)",
    "renamed file" : "ficheiro renomeado",
    "\"%1$s\" is a forbidden file or folder name." : "«%1$s» é un nome de ficheiro ou cartafol prohibido.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "«%1$s» é un prefixo prohibido para os nomes de ficheiros ou cartafoles.",
    "\"%1$s\" is not allowed inside a file or folder name." : "«%1$s» non está permitido nun nome de ficheiro ou cartafol.",
    "\"%1$s\" is a forbidden file type." : "«%1$s» é un tipo de ficheiro prohibido.",
    "Filenames must not end with \"%1$s\"." : "Os nomes de ficheiros non deben rematar con «%1$s».",
    "Invalid parent path" : "A ruta principal non é correcta",
    "File already exists" : "O ficheiro xa existe",
    "Invalid path" : "A ruta non é correcta.",
    "Failed to create file from template" : "Produciuse un fallo ao crear un ficheiro a partir do modelo",
    "Templates" : "Modelos",
    "Storage %s cannot be moved" : "Non é posíbel mover o almacenamento %s",
    "Moving a share (%s) into a shared folder is not allowed" : "Non está permitido mover un recurso compartido (%s) a un cartafol compartido",
    "Moving a storage (%s) into a shared folder is not allowed" : "Non está permitido mover un almacenamento (%s) a un cartafol compartido",
    "Moving a share (%s) into another share (%s) is not allowed" : "Non está permitido mover un recurso compartido (%s) cara a outro recurso compartido (%s)",
    "Moving a share (%s) into another storage (%s) is not allowed" : "Non está permitido mover un recurso compartido (%s) cara a outro almacenamento (%s)",
    "Moving a storage (%s) into a share (%s) is not allowed" : "Non está permitido mover un recurso compartido (%s) cara a un recurso compartido (%s)",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "Non está permitido mover un almacenamento (%s) cara a outro almacenamento (%s)",
    "Path contains invalid segments" : "A ruta contén segmentos non válidos",
    "Filename is a reserved word" : "O nome de ficheiro é unha palabra reservada",
    "Filename contains at least one invalid character" : "O nome de ficheiro contén algún carácter non aceptado",
    "Filename is too long" : "O nome de ficheiro é longo de máis",
    "Empty filename is not allowed" : "Non está permitido deixar baleiro o nome de ficheiro",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Non é posíbel instalar a aplicación «%s» por mor de non poder ler o ficheiro appinfo.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Non é posíbel instalar a aplicación «%s» por mor de non ser compatíbel con esta versión do servidor.",
    "__language_name__" : "Galego",
    "This is an automatically sent email, please do not reply." : "Este é un correo enviado automaticamente, non responda.",
    "Help & privacy" : "Axuda e privacidade",
    "Appearance and accessibility" : "Aspecto e accesibilidade",
    "Apps" : "Aplicacións",
    "Personal settings" : "Axustes persoais",
    "Administration settings" : "Axustes de administración",
    "Settings" : "Axustes",
    "Log out" : "Saír",
    "Accounts" : "Contas",
    "Bluesky" : "Bluesky",
    "View %s on Bluesky" : "Ver %s en Bluesky",
    "Email" : "Correo-e",
    "Mail %s" : "Correo %s",
    "Fediverse" : "Fediverso",
    "View %s on the fediverse" : "Ver %s no fediverso",
    "Phone" : "Teléfono",
    "Call %s" : "Chamar %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Ver %s en Twitter",
    "Website" : "Sitio web",
    "Visit %s" : "Visitar %s",
    "Address" : "Enderezo",
    "Profile picture" : "Imaxe do perfil",
    "About" : "Sobre",
    "Display name" : "Nome para amosar",
    "Headline" : "Titular",
    "Organization" : "Organización",
    "Role" : "Cargo",
    "Pronouns" : "Pronomes",
    "Unknown account" : "Conta descoñecida",
    "Additional settings" : "Axustes adicionais",
    "Enter the database Login and name for %s" : "Introduza o acceso a base de datos e o nome para %s",
    "Enter the database Login for %s" : "Introduza o acceso a base de datos para %s",
    "Enter the database name for %s" : "Introduza o nome da base de datos para %s",
    "You cannot use dots in the database name %s" : "Non pode usar puntos no nome da base de datos %s",
    "MySQL Login and/or password not valid" : "O acceso de MySQL e/ou o contrasinal non son válidos",
    "You need to enter details of an existing account." : "Debe introducir os detalles dunha conta existente.",
    "Oracle connection could not be established" : "Non foi posíbel estabelecer a conexión con Oracle",
    "Oracle Login and/or password not valid" : "O acceso de Oracle e/ou o contrasinal non son válidos",
    "PostgreSQL Login and/or password not valid" : "O acceso de PostgreSQL e/ou o contrasinal non son válidos",
    "For the best results, please consider using a GNU/Linux server instead." : "Para obter mellores resultados, considere o emprego dun servidor GNU/Linux en troques.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Semella que esta instancia de %s está a funcionar nun contorno PHP de 32 bisst e o open_basedir foi configurado no php.ini. Isto provocará problemas con ficheiros maiores de 4 GB e está absolutamente desaconsellado.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Retire o axuste de open_basedir no php.ini ou cambie a PHP de 64 bits.",
    "Set an admin Login." : "Definir un acceso de administración",
    "Set an admin password." : "Estabeleza un contrasinal de administrador",
    "Cannot create or write into the data directory %s" : "Non é posíbel crear ou escribir no directorio de datos %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A infraestrutura de compartición %s ten que implementar a interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Non se atopou a infraestrutura de compartición %s",
    "Sharing backend for %s not found" : "Non se atopou a infraestrutura de compartición para %s",
    "%1$s shared %2$s with you" : "%1$s compartiu %2$s con Vde.",
    "Open %s" : "Abrir %s",
    "%1$s via %2$s" : "%1$s mediante %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s compartiu %2$s con Vde. e quere engadir:",
    "%1$s shared %2$s with you and wants to add" : "%1$s compartiu %2$s con Vde. e quere engadir",
    "%s added a note to a file shared with you" : "%s engadiu unha nota a un ficheiro compartido con Vde.",
    "Passwords are enforced for link and mail shares" : "É obrigatorio o emprego de contrasinais para compartir por ligazón e por correo",
    "Share recipient is not a valid user" : "O destinatario da compartición non é un usuario válido",
    "Share recipient is not a valid group" : "O destinatario da compartición non é un grupo válido",
    "Share recipient should be empty" : "O destinatario da compartición debe estar baleiro",
    "Share recipient should not be empty" : "O destinatario da compartición non debe estar baleiro",
    "Share recipient is not a valid circle" : "O destinatario da compartición non é un círculo válido",
    "Unknown share type" : "Tipo descoñecido de compartición",
    "Share initiator must be set" : "Debe estar definido quen inicia a compartición",
    "Cannot share with yourself" : "Non é posíbel compartir con un mesmo.",
    "Shared path must be set" : "Debe estar definida a ruta compartida",
    "Shared path must be either a file or a folder" : "A ruta compartida debe ser a un ficheiro ou un cartafol",
    "You cannot share your root folder" : "Non pode compartir o seu cartafol raíz",
    "You are not allowed to share %s" : "Vde. non ten permiso para compartir %s",
    "Valid permissions are required for sharing" : "Precisanse permisos válidos para compartir",
    "File shares cannot have create or delete permissions" : "As comparticións de ficheiros non poden crear ou eliminar permisos",
    "Cannot increase permissions of %s" : "Non é posíbel incrementar os permisos de %s",
    "Shares need at least read permissions" : "As comparticións necesitan polo menos permisos de lectura",
    "Files cannot be shared with delete permissions" : "Non é posíbel compartir ficheiros con permisos de eliminación",
    "Files cannot be shared with create permissions" : "Non é posíbel compartir ficheiros con permisos de creación",
    "Expiration date is in the past" : "Xa pasou a data de caducidade",
    "Expiration date is enforced" : "A data de caducidade é obrigatoria",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Non é posíbel definir a data de caducidade máis alo de %n día no futuro","Non é posíbel definir a data de caducidade máis alo de %n días no futuro"],
    "Sharing is only allowed with group members" : "Só se permite compartir cos membros do grupo",
    "Sharing %s failed, because this item is already shared with the account %s" : "Produciuse un fallo ao compartir %s, porque este elemento xa se comparte coa conta %s",
    "Group sharing is now allowed" : "Agora está permitida a compartición en grupo",
    "Sharing is only allowed within your own groups" : "Só se permite compartir dentro dos seus propios grupos",
    "Path is already shared with this group" : "A ruta xa está compartida con este grupo",
    "Link sharing is not allowed" : "Non se permite compartir ligazóns",
    "Public upload is not allowed" : "Non se permite o envío público",
    "You cannot share a folder that contains other shares" : "Non pode compartir un cartafol que conteña outras comparticións",
    "Sharing is disabled" : "A compartición está desactivada",
    "Sharing is disabled for you" : "A compartición está desactivada para Vde.",
    "Cannot share with the share owner" : "Non é posíbel compartir co propietario do compartido",
    "Share does not have a full ID" : "A compartición non ten unha ID completa",
    "Cannot change share type" : "Non é posíbel cambiar o tipo de compartición",
    "Can only update recipient on user shares" : "Só é posíbel actualizar o destinatario nas comparticións por usuarios",
    "Cannot enable sending the password by Talk with an empty password" : "Non é posíbel activar o envío do contrasinal mediante Parladoiro cun contrasinal baleiro",
    "Cannot enable sending the password by Talk without setting a new password" : "Non é posíbel activar o envío do contrasinal mediante Parladoiro sen definir un novo contrasinal",
    "Cannot disable sending the password by Talk without setting a new password" : "Non é posíbel desactivar o envío do contrasinal medainte sen definir un novo contrasinal",
    "Share provider does not support accepting" : "O provedor de comparticións non admite a aceptación",
    "Cannot change target of link share" : "Non é posíbel cambiar o destino da ligazón para compartir",
    "Invalid share recipient" : "Destinatario de compartición incorrecto",
    "Group \"%s\" does not exist" : "O grupo «%s» non existe",
    "The requested share does not exist anymore" : "A compartición solicitada xa non existe",
    "The requested share comes from a disabled user" : "A compartición solicitada procede dun usuario desactivado",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Non se creou o usuario porque acadouse o límite de usuarios. Consulte as súas notificacións para obter máis información.",
    "Could not find category \"%s\"" : "Non foi posíbel atopar a categoría «%s»",
    "Input text" : "Texto de entrada",
    "The input text" : "O texto de entrada",
    "Sunday" : "domingo",
    "Monday" : "luns",
    "Tuesday" : "martes",
    "Wednesday" : "mércores",
    "Thursday" : "xoves",
    "Friday" : "venres",
    "Saturday" : "sábado",
    "Sun." : "dom.",
    "Mon." : "lun.",
    "Tue." : "mar.",
    "Wed." : "mér.",
    "Thu." : "xov.",
    "Fri." : "ven.",
    "Sat." : "sáb.",
    "Su" : "do",
    "Mo" : "lu",
    "Tu" : "ma",
    "We" : "mé",
    "Th" : "xo",
    "Fr" : "ve",
    "Sa" : "sá",
    "January" : "xaneiro",
    "February" : "febreiro",
    "March" : "marzo",
    "April" : "abril",
    "May" : "maio",
    "June" : "xuño",
    "July" : "xullo",
    "August" : "agosto",
    "September" : "setembro",
    "October" : "outubro",
    "November" : "novembro",
    "December" : "decembro",
    "Jan." : "xan.",
    "Feb." : "feb.",
    "Mar." : "mar.",
    "Apr." : "abr.",
    "May." : "mai.",
    "Jun." : "xuñ.",
    "Jul." : "xul.",
    "Aug." : "ago.",
    "Sep." : "set.",
    "Oct." : "out.",
    "Nov." : "nov.",
    "Dec." : "dec.",
    "A valid password must be provided" : "Debe fornecer un contrasinal",
    "The Login is already being used" : "O acceso xa se está a usar",
    "Could not create account" : "Non foi posíbel crear a conta",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Só se permiten os seguintes caracteres nun acceso: «a-z», «A-Z», «0-9», espazos e «_.@-'»",
    "A valid Login must be provided" : "Ten que fornecer un acceso válido",
    "Login contains whitespace at the beginning or at the end" : "O acceso contén espazos en branco ao comezo ou ao final",
    "Login must not consist of dots only" : "O acceso non debe estar composto só por puntos",
    "Username is too long" : "O nome de usuario é longo de máis",
    "Login is invalid because files already exist for this user" : "O acceso non é válido porque xa existen ficheiros para este usuario",
    "Account disabled" : "Conta desactivada",
    "Login canceled by app" : "Acceso cancelado pola aplicación",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Non é posíbel instalar a aplicación «%1$s» por mor de non cumprirse as dependencias: %2$s",
    "a safe home for all your data" : "un acubillo seguro para todos os seus datos",
    "Application is not enabled" : "A aplicación non está activada",
    "Authentication error" : "Produciuse un erro de autenticación",
    "Token expired. Please reload page." : "Testemuño caducado. Recargue a páxina.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Non hai controladores de base de datos (sqlite, mysql, ou postgresql) instalados.",
    "Cannot write into \"config\" directory." : "Non é posíbel escribir no directorio «config».",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Isto, normalmente, pódese solucionar dándolle ao servidor web acceso de escritura ao directorio de configuración. Véxa %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, se prefire conservar o ficheiro «config.php» como de só lectura, marque a opción «config_is_read_only» como «true» nel. Vexa %s",
    "Cannot create \"data\" directory." : "Non é posíbel crear o directorio «data».",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Isto, normalmente, pódese solucionar dándolle ao servidor web acceso de escritura ao directorio raíz. Véxa %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Os permisos normalmente pódense corrixir dándolle ao servidor web acceso de escritura ao directorio raíz. Véxa %s.",
    "Your data directory is not writable." : "Non se pode escribir no seu directorio de datos.",
    "Setting locale to %s failed." : "Produciuse un fallo ao axustar a configuración rexional en %s.",
    "Please install one of these locales on your system and restart your web server." : "Instale un destes locais no seu sistema e reinicie o seu servidor web.",
    "PHP module %s not installed." : "O módulo PHP %s non está instalado.",
    "Please ask your server administrator to install the module." : "Pídalle á administración do seu servidor que instale o módulo.",
    "PHP setting \"%s\" is not set to \"%s\"." : "O axuste de PHP «%s» non está estabelecido a «%s».",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Cambiar este axuste no ficheiro php.ini fará que Nextcloud funcione de novo",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Semella que PHP foi configurado para quitar bloques de documentos en liña. Isto fará que varios aplicativos sexan inaccesíbeis. ",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto probabelmente se debe unha memoria tobo/acelerador como Zend OPcache ou eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Instaláronse os módulos de PHP, mais aínda aparecen listados como perdidos?",
    "Please ask your server administrator to restart the web server." : "Pídalle á administración do seu servidor que reinicie o servidor web.",
    "The required %s config variable is not configured in the config.php file." : "Precísase da variábel de configuración %s e non está configurada no ficheiro config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Pídalle á administración do seu servidor que verifique a configuración de Nextcloud.",
    "Your data directory is readable by other people." : "Outras persoas poden ler o seu directorio de datos.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Cambie os permisos a 0770 para que o directorio non poida ser listado por outras persoas.",
    "Your data directory must be an absolute path." : "O seu directorio de datos debe ser unha ruta absoluta.",
    "Check the value of \"datadirectory\" in your configuration." : "Comprobe o valor de «datadirectory» na súa configuración-",
    "Your data directory is invalid." : "O seu directorio de datos non é válido.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Asegúrese de que existe un ficheiro chamado «%1$s» na raíz do directorio de datos. Debería ter o contido: «%2$s»",
    "Action \"%s\" not supported or implemented." : "A acción «%s» non está admitida ou implementada.",
    "Authentication failed, wrong token or provider ID given" : "Produciuse un fallo de autenticación. Deuse un testemuño ou un ID de provedor erróneos.",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Faltan parámetros para completar a solicitude. Parámetros que faltan: «%s»",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "O ID «%1$s» xa está a ser usado polo provedor da nube federada «%2$s»",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "O  provedor de nube federada co ID «%s» non existe.",
    "Could not obtain lock type %d on \"%s\"." : "Non foi posíbel obter un bloqueo do tipo %d en «%s».",
    "Storage unauthorized. %s" : "Almacenamento non autorizado. %s",
    "Storage incomplete configuration. %s" : "Configuración incompleta do almacenamento. %s",
    "Storage connection error. %s" : "Produciuse un erro na conexión ao almacenamento. %s",
    "Storage is temporarily not available" : "O almacenamento non está dispoñíbel temporalmente",
    "Storage connection timeout. %s" : "Esgotouse o tempo de conexión co almacenamento. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Para permitir que esta comprobación se execute, debe asegurarse de que o seu servidor web poida conectarse a si mesmo. Por tanto, debe ser quen de resolver e conectarse a polo menos un dos seus «trusted_domains» ou ao «overwrite.cli.url». Este fallo pode ser o resultado dunha falta de coincidencia de DNS do servidor ou dunha regra da devasa de saída.",
    "Analyze images" : "Analizar as imaxes",
    "Ask a question about the given images." : "Formule unha pregunta sobre as imaxes indicadas.",
    "Images" : "Imaxes",
    "Images to ask a question about" : "Imaxes sobre as que facer unha pregunta",
    "Question" : "Pregunta",
    "What to ask about the images." : "Que preguntar sobre as imaxes.",
    "Generated response" : "Resposta xerada",
    "The answer to the question" : "A resposta á pregunta",
    "Audio chat" : "Parola de son",
    "Voice chat with the assistant" : "Parola de voz co asistente",
    "System prompt" : "Indicador do sistema",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Definir regras e supostos que o asistente debe seguir durante a conversa.",
    "Chat voice message" : "Mensaxe de voz de parola",
    "Describe a task that you want the assistant to do or ask a question." : "Describa unha tarefa que quere que realice o asistente ou formule unha pregunta.",
    "Chat history" : "Historial de parola",
    "The history of chat messages before the current message, starting with a message by the user." : "O historial das mensaxes de parola antes da mensaxe actual, comezando cunha mensaxe do usuario.",
    "Input transcript" : "Transcrición de entrada",
    "Transcription of the audio input" : "Transcrición da entrada de son",
    "Response voice message" : "Mensaxe de voz de resposta",
    "The generated voice response as part of the conversation" : "A resposta de voz xerada como parte da conversa",
    "Output transcript" : "Transcrición de saída",
    "Transcription of the audio output" : "Transcrición da saída de son",
    "Transcribe audio" : "Transcribir son",
    "Transcribe the things said in an audio" : "Transcribir as cousas ditas nun ficheiro de son",
    "Audio input" : "Entrada de son",
    "The audio to transcribe" : "O audio para transcribir",
    "Transcription" : "Transcrición",
    "The transcribed text" : "O texto transcrito",
    "Chat by voice with an agent" : "Parola por voz cun axente",
    "Describe a task that you want the agent to do or ask a question." : "Describa unha tarefa que quere que realice o axente ou formule unha pregunta.",
    "Confirmation" : "Confirmación",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Indica se hai que confirmar as accións solicitadas anteriormente: 0 para a denegación e 1 para a confirmación.",
    "Conversation token" : "Testemuño de conversa",
    "A token representing the conversation." : "Un testemuño que representa a conversa.",
    "The new conversation token" : "O novo testemuño de conversa",
    "Send this along with the next interaction." : "Envía isto xunto coa seguinte interacción.",
    "Requested actions by the agent" : "Accións solicitadas polo axente",
    "Actions that the agent would like to carry out in JSON format." : "Accións que o axente quere levar a cabo en formato JSON.",
    "Chat with an agent" : "Parolar cun axente",
    "Chat message" : "Mensaxe de parola",
    "A chat message to send to the agent." : "Unha mensaxe de parola para enviar ao axente.",
    "The response from the chat model." : "A resposta do modelo de parola.",
    "Context write" : "Redacción por contexto",
    "Writes text in a given style based on the provided source material." : "Escribe texto nun estilo determinado baseándose no material orixinal fornecido.",
    "Writing style" : "Estilo de escritura",
    "Demonstrate a writing style that you would like to immitate" : "Demostre un estilo de escritura que lle gustaría imitar",
    "Source material" : "Material orixinal",
    "The content that would like to be rewritten in the new writing style" : "O contido que quere que sexa reescrito no novo estilo de escritura",
    "Generated text" : "Texto xerado",
    "The generated text with content from the source material in the given style" : "O texto xerado con contido do material orixinal no estilo indicado",
    "Emoji generator" : "Xerador de «emojis»",
    "Takes text and generates a representative emoji for it." : "Toma texto e xera un «emoji» representativo para el.",
    "The text to generate an emoji for" : "O texto para xerar un «emoji»",
    "Generated emoji" : "«Emoji» xerado",
    "The generated emoji based on the input text" : "O «emoji» xerado en función do texto introducido",
    "Optical character recognition" : "Recoñecemento óptico de caracteres",
    "Extract text from files like images or PDFs" : "Extraer texto de ficheiros como imaxes ou PDF",
    "Input files" : "Ficheiros de entrada",
    "The files to extract text from" : "Os ficheiros dos que extraer o texto",
    "Output texts" : "Textos de saída",
    "The texts that were extracted from the files" : "Os textos que foron extraídos dos ficheiros",
    "Generate image" : "Xerar imaxe",
    "Generate an image from a text prompt" : "Xerar unha imaxe a partir dunha indicación de texto",
    "Prompt" : "Indicación",
    "Describe the image you want to generate" : "Describa a imaxe que quere xerar",
    "Number of images" : "Número de imaxes",
    "How many images to generate" : "Cantas imaxes xerar",
    "Output images" : "Imaxes de saída",
    "The generated images" : "As imaxes xeradas",
    "Generate speech" : "Xerar parrafeo",
    "Generate speech from a transcript" : "Xerar parrafeo a partir dunha transcrición",
    "Write transcript that you want the assistant to generate speech from" : "Escriba a transcrición da que quere que o asistente xere o parrafeo",
    "Output speech" : "Parrafeo de saída",
    "The generated speech" : "O parrafeo xerado",
    "Free text to text prompt" : "Texto libre para indicación de texto",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Procesa unha indicación arbitraria a través dun modelo de linguaxe que devolve unha resposta",
    "Describe a task that you want the assistant to do or ask a question" : "Describa unha tarefa que quere que realice o asistente ou formule unha pregunta",
    "Generated reply" : "Resposta xerada",
    "The generated text from the assistant" : "O texto xerado polo asistente",
    "Change Tone" : "Cambiar o ton",
    "Change the tone of a piece of text." : "Cambia o ton dun fragmento de texto.",
    "Write a text that you want the assistant to rewrite in another tone." : "Escriba un texto que queira que sexa reformulado polo asistente noutro ton",
    "Desired tone" : "Ton desexado",
    "In which tone should your text be rewritten?" : "En que ton debe reescribirse o texto?",
    "The rewritten text in the desired tone, written by the assistant:" : "O texto reformulado no ton desexado, escrito polo asistente",
    "Chat" : "Parola",
    "Chat with the assistant" : "Parola co asistente",
    "The history of chat messages before the current message, starting with a message by the user" : "O historial das mensaxes de parola antes da mensaxe actual, comezando cunha mensaxe do usuario",
    "Response message" : "Mensaxe de resposta",
    "The generated response as part of the conversation" : "A resposta xerada como parte da conversa",
    "Chat with tools" : "Parola con ferramentas",
    "Chat with the language model with tool calling support." : "Parola co modelo de linguaxe axuda da ferramenta de chamada",
    "Tool message" : "Mensaxe da ferramenta",
    "The result of tool calls in the last interaction" : "O resultado das chamadas de ferramenta na última interacción",
    "Available tools" : "Ferramentas dispoñíbeis",
    "The available tools in JSON format" : "As ferramentas dispoñíbeis en formato JSON",
    "The response from the chat model" : "A resposta do modelo de parola",
    "Tool calls" : "Chamadas da ferramenta",
    "Tools call instructions from the model in JSON format" : "As ferramentas chaman ás instrucións do modelo en formato JSON",
    "Formalize text" : "Formalizar texto",
    "Takes a text and makes it sound more formal" : "Toma un texto e fai que soe máis formal",
    "Write a text that you want the assistant to formalize" : "Escriba un texto que queira que sexa formalizado polo asistente",
    "Formalized text" : "Texto formalizado",
    "The formalized text" : "O texto formalizado",
    "Generate a headline" : "Xerar un titular",
    "Generates a possible headline for a text." : "Xera un posíbel titular para un texto.",
    "Original text" : "Texto orixinal",
    "The original text to generate a headline for" : "O texto orixinal para xerar un titular",
    "The generated headline" : "O titular xerado",
    "Proofread" : "Revisión",
    "Proofreads a text and lists corrections" : "Revisa un texto e enumera as correccións",
    "Text" : "Texto",
    "The text to proofread" : "O texto para revisar",
    "Corrections" : "Correccións",
    "The corrections that should be made in your text" : "As correccións que se deben facer no seu texto",
    "Reformulate text" : "Reformular texto",
    "Takes a text and reformulates it" : "Toma un texto e reformúlao",
    "Write a text that you want the assistant to reformulate" : "Escriba un texto que queira que sexa reformulado polo asistente",
    "Reformulated text" : "Texto reformulado",
    "The reformulated text, written by the assistant" : "O texto reformulado, escrito polo asistente",
    "Simplify text" : "Simplificar texto",
    "Takes a text and simplifies it" : "Toma un texto e simplifícao",
    "Write a text that you want the assistant to simplify" : "Escriba un texto que queira que sexa simplificado polo asistente",
    "Simplified text" : "Texto simplificado",
    "The simplified text" : "O texto simplificado",
    "Summarize" : "Resumir",
    "Summarizes a text" : "Resume un texto",
    "The original text to summarize" : "O texto orixinal para resumir",
    "Summary" : "Resumo",
    "The generated summary" : "O resumo xerado",
    "Extract topics" : "Extraer temas",
    "Extracts topics from a text and outputs them separated by commas" : "Extrae temas dun texto e amósaos separados por comas",
    "The original text to extract topics from" : "O texto orixinal para extraer temas",
    "Topics" : "Temas",
    "The list of extracted topics" : "A lista de temas extraídos",
    "Translate" : "Traducir",
    "Translate text from one language to another" : "Traducir texto dun idioma a outro",
    "Origin text" : "Texto orixinal",
    "The text to translate" : "O texto a traducir",
    "Origin language" : "Idioma do orixinal",
    "The language of the origin text" : "O idioma do texto orixinal",
    "Target language" : "Idioma de destino",
    "The desired language to translate the origin text in" : "O idioma desexado para traducir o texto orixinal",
    "Result" : "Resultado",
    "The translated text" : "O texto traducido",
    "Free prompt" : "Indicación libre",
    "Runs an arbitrary prompt through the language model." : "Procesa unha indicación arbitraria a través do modelo de linguaxe.",
    "Generate headline" : "Xerar titular",
    "Summarizes text by reducing its length without losing key information." : "Resume o texto reducindo a súa lonxitude sen perder a información clave.",
    "Extracts topics from a text and outputs them separated by commas." : "Extrae temas dun texto e amósaos separados por comas.",
    "Organisation" : "Organización",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X non é compatíbel e %s non funcionará correctamente nesta plataforma. Utilíceo baixo a súa responsabilidade!",
    "Login is too long" : "O acceso é longo de máis",
    "Cannot write into \"apps\" directory." : "Non é posíbel escribir no directorio «apps».",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Isto, normalmente, pódese solucionar dándolle ao servidor web acceso de escritura ao directorio de aplicacións ou desactivando a tenda de aplicacións no ficheiro de configuración.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está estabelecido en <code>%s</code> en troques do valor agardado <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para solucionar este problema, estabeleza <code>mbstring.func_overload</code> en <code>0</code> no seu php.ini."
},
"nplurals=2; plural=(n != 1);");
